/**
 * (C) COPYRIGHT International Business Machines Corp. 2012, All Rights Reserved
 * US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */
var SESSION_TIMEOUT = (function($) {
    var my = {
        suiteAppUrls: null,
        properties: null,
        messages: null
    };
    var windowMode = null;

    function isModalDialog(obj) {
        return typeof obj.dialogArguments !== 'undefined';
    }

    function isNonModalDialog(obj) {
        return obj.opener != null && obj.opener != obj && obj.name != null && obj.name.length != 0;
    }

    function prepareForClosure(obj) {
        try {
            obj.onbeforeunload = null;
            obj.onunload = null;
        }
        catch (exc) {}
        try {
            $.each(obj.frames, function(i, frame) {
                prepareForClosure(frame.contentWindow);
            });
        }
        catch (exc) {}
    }

    function closeWindow(obj) {
        if (typeof obj.closed == 'undefined') {
            return;
        }
        if (obj.closed) {
            return;
        }
        prepareForClosure(obj);
        try {
            obj.close();
        }
        catch (exc) {}
    }

    function registerDialog() {
        var target = my.suiteAppUrls[0] + "/list-dialogs.jsp?name=" + window.name;
        $.ajax({
            url: target,
            cache: false,
            dataType: 'json',
            complete: function() { /* no-op */ }
        });
    }

    function initIdleTimer() {
        $("#idletimeout").html(my.messages.message_pre
            + '&nbsp;<span></span>&nbsp;' + my.messages.message_post
            + '&nbsp;<a id="idletimeout-resume" href="#">' + my.messages.message_link
            + '&nbsp;</a>');

        $.idleTimeout('#idletimeout', '#idletimeout a', {
            idleAfter:       my.properties.timeout   || 1200,  // default 20 minutes of inactivity
            warningLength:   my.properties.countdown || 20,    // default 20 second countdown before logout
            pollingInterval: my.properties.heartbeat || 600,   // default 10 minutes between heartbeats
            keepAlivePage: '/keep-alive.jsp',
            keepAliveURLs: my.suiteAppUrls,
            onTimeout: function() {
                if (isModalDialog(window)) {
                    var w = 200;
                    var h = 100;
                    var l = (screen.width - w) / 2;
                    var t = (screen.height - h) / 2;
                    var name = 'logout' + (+new Date);
                    window.open(my.suiteAppUrls[0] + '/logout.jsp?dialog=true', name,
                        'toolbar=no,location=no,status=no,menubar=no,scrollbars=no,resizable=no,'
                        + 'directories=no,copyhistory=no,width='+w+',height='+h+',top='+t+',left='+l);
                }
                else if (windowMode != 'base' && isNonModalDialog(window)) {
                    closeWindow(window);
                }
                else {
                    window.location = my.suiteAppUrls[0] + '/logout.jsp?timeout=true';
                }
            },
            onIdle: function() {
                $(this).slideDown(); // show the warning bar
            },
            onCountdown: function(counter) {
                $(this).find("span").html(counter); // update the counter
            },
            onResume: function() {
                $(this).slideUp(); // hide the warning bar
            }
        });
    }

    return {
        config: function(configuration) {
            // Just clone the configuration passed in.
            my = $.extend({}, configuration);
            if (arguments.length > 1) {
                windowMode = arguments[1];
            }
        },

        display: function() {
            this.register();
        },

        /**
         * Perform registration only for dialogs and keep-alive.
         * @returns void
         */
        register: function() {
            if ($("#idletimeout").size() == 0) {
                $('<div id="idletimeout">').prependTo("body");
            }
            if (windowMode != 'base' && isNonModalDialog(window)) {
                registerDialog();
            }
            initIdleTimer();
        }
    };
})(jQuery);
