""" 
 * (C) COPYRIGHT International Business Machines Corp. 2012, 2013, 2014. All Rights Reserved
 * US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
"""
#######################################################################
# wsadmin script to configure Emptoris SSM
#
# Any scripting which relies on the existence of the Emptoris security
# domain (created in configure_sso.py) should go here.  Most other
# scripting should be done in gateway.py itself.
#######################################################################

########### Start Imports ###########
import re
import util.utility as util

import was_objs.import_was as wasScript
execfile(wasScript.__file__)
########### End Imports ###########

def getRequiredProperty(name):
	"""Get the value of a named argument.  Raise an Exception if the property is None."""
	value = getProperty(name)
	if value is None:
		raise Exception('Non-null value must be specified for argument [' + name + ']')
	return value


def getProperty(name, default=None):
	"""Get the value of a property.  If not found, return default.  If default not specified, return None."""
	if name in args.keys():
		return args[name]
	else:
		return default


########### Start Variable Definitions ###########
secDomainName = getProperty('securityDomainName', 'Emptoris')
casValidatorUrl = getProperty('casAuthenticationUrl')
########### End Variable Definitions ###########

try:
	print "Configuring IBM Emptoris Strategic Supply Management Security..."

	# The following cleans up certificate imports that were performed prior to the introduction of the common bootstrap script.  These will be refetched as necessary.
	print "Cleaning up old certificate aliases."
	try:
		keyStoreName = 'NodeDefaultTrustStore'
		storeNameAndAlias = {}
		storeNameAndAlias.update({'keyStoreName' : keyStoreName})
	
		grepper = re.compile("alias \[?([^]]+)")
		
		aliasesToDelete = {'vsm1_cert':'', 'ecm1_cert':'', 'ecm2_cert':'', 'ecm3_cert':'', 'ecm4_cert':'', 'ecm5_cert':'', 'ecm6_cert':''}
		for signer in AdminTask.listSignerCertificates(util.toArgString({'keyStoreName' : keyStoreName})).splitlines():
			m = grepper.search(signer)
			if m is not None:
				foundAlias = m.groups()[0]
				if foundAlias in aliasesToDelete.keys():
					print "Removing signer certificate with alias [" + str(foundAlias) + "]."
					storeNameAndAlias.update({'certificateAlias' : foundAlias})
					AdminTask.deleteSignerCertificate(util.toArgString(storeNameAndAlias))
	except Exception, e:
		print "Error while deleting signer certificate: " + str(storeNameAndAlias)
		print str(e)

	# Configure CAS authentication URL
	if casValidatorUrl is not None and casValidatorUrl != "":
		print "Configuring Emptoris CAS TAI authentication URL [" + casValidatorUrl + "]..."
		AdminTask.configureTrustAssociation('[-securityDomainName ' + secDomainName + ' -enable true]')
		AdminTask.configureInterceptor('[-interceptor com.emptoris.cas.CASTAI  -securityDomainName ' + secDomainName + ' -customProperties["com.emptoris.cas.authentication.url=' + casValidatorUrl +'"]]') 

	print "Configuring Audit Logging..."
	asp = auditServiceProvider.AuditServiceProvider('ssmAuditProviderImpl_1')
	asp.setClassName('com.emptoris.audit.WSAuditServiceProvider')
	asp.setEventFormatterClass('com.emptoris.audit.WSAuditServiceProvider')
	asp.setAuditSpecifications(['DefaultAuditSpecification_1', 'DefaultAuditSpecification_2', 'DefaultAuditSpecification_4'])
	asp.addCustomProperty('jndiDataSourcePath', args['urDataSourceJndiName'])
	asp.addCustomProperty('auditApplications', 'Rivermine 6.0,/j_security_check,/gateway/')
	asp.configure()

	aef = auditEventFactory.AuditEventFactory('ssmAuditProviderImpl_1')
	aef.setClassName('com.ibm.ws.security.audit.AuditEventFactoryImpl')
	aef.setAuditServiceProvider(asp)
	aef.setAuditSpecifications(['DefaultAuditSpecification_1', 'DefaultAuditSpecification_2', 'DefaultAuditSpecification_4'])
	aef.configure()

	policy = auditPolicy.AuditPolicy()
	policy.setAuditEnabled('true')
	policy.configure()
	
	print "Saving changes..."
	AdminConfig.save()
	print "Changes saved."

except Exception, e:
	print "Server configuration failed.  Rolling back changes."
	AdminConfig.reset()
	raise # Re-throw to terminate the script